gleemenu
Functions
pub fn show(
menu command: Command,
with choices: List(String),
) -> Result(String, Error)
Display a list of choices using the provided dmenu command.
pub fn show_tree(
tree tree: Tree(a),
with command: Command,
) -> Result(a, Error)
Display a menu tree using the provided dmenu command.
You can create a menu tree using menu.new!